Skip to main contentModule linked_lists
Source - Double
Double is a double linked list referencing the head, the tail node node and the length of the list.- Singly
Singly is a singly linked list that contains a reference to the head node and the length of the list.